@@ -3,6 +3,7 @@ use actix_web::web::Data;
 use lemmy_api_common::{
   blocking,
   check_community_ban,
+  check_community_deleted_or_removed,
   check_downvotes_enabled,
   check_person_block,
   get_local_user_view_from_jwt,
@@ -11,18 +12,21 @@ use lemmy_api_common::{
   post::*,
 };
 use lemmy_apub::{
-  activities::{
-    post::create_or_update::CreateOrUpdatePost,
+  fetcher::post_or_comment::PostOrComment,
+  objects::post::ApubPost,
+  protocol::activities::{
+    create_or_update::post::CreateOrUpdatePost,
     voting::{
       undo_vote::UndoVote,
       vote::{Vote, VoteType},
     },
     CreateOrUpdateType,
   },
-  fetcher::post_or_comment::PostOrComment,
 };
-use lemmy_db_queries::{source::post::Post_, Crud, Likeable, Saveable};
-use lemmy_db_schema::source::{moderator::*, post::*};
+use lemmy_db_schema::{
+  source::{moderator::*, post::*},
+  traits::{Crud, Likeable, Saveable},
+};
 use lemmy_db_views::post_view::PostView;
 use lemmy_utils::{request::fetch_site_metadata, ApiError, ConnectionId, LemmyError};
 use lemmy_websocket::{send::send_post_ws_message, LemmyContext, UserOperation};
@@ -46,9 +50,12 @@ impl Perform for CreatePostLike {
 
     // Check for a community ban
     let post_id = data.post_id;
-    let post = blocking(context.pool(), move |conn| Post::read(conn, post_id)).await??;
+    let post: ApubPost = blocking(context.pool(), move |conn| Post::read(conn, post_id))
+      .await??
+      .into();
 
     check_community_ban(local_user_view.person.id, post.community_id, context.pool()).await?;
+    check_community_deleted_or_removed(post.community_id, context.pool()).await?;
 
     check_person_block(local_user_view.person.id, post.creator_id, context.pool()).await?;
 
@@ -79,7 +86,7 @@ impl Perform for CreatePostLike {
 
       Vote::send(
         &object,
-        &local_user_view.person,
+        &local_user_view.person.clone().into(),
         community_id,
         like_form.score.try_into()?,
         context,
@@ -89,7 +96,7 @@ impl Perform for CreatePostLike {
       // API doesn't distinguish between Undo/Like and Undo/Dislike
       UndoVote::send(
         &object,
-        &local_user_view.person,
+        &local_user_view.person.clone().into(),
         community_id,
         VoteType::Like,
         context,
@@ -133,6 +140,7 @@ impl Perform for LockPost {
       context.pool(),
     )
     .await?;
+    check_community_deleted_or_removed(orig_post.community_id, context.pool()).await?;
 
     // Verify that only the mods can lock
     is_mod_or_admin(
@@ -145,10 +153,11 @@ impl Perform for LockPost {
     // Update the post
     let post_id = data.post_id;
     let locked = data.locked;
-    let updated_post = blocking(context.pool(), move |conn| {
+    let updated_post: ApubPost = blocking(context.pool(), move |conn| {
       Post::update_locked(conn, post_id, locked)
     })
-    .await??;
+    .await??
+    .into();
 
     // Mod tables
     let form = ModLockPostForm {
@@ -160,8 +169,8 @@ impl Perform for LockPost {
 
     // apub updates
     CreateOrUpdatePost::send(
-      &updated_post,
-      &local_user_view.person,
+      updated_post,
+      &local_user_view.person.clone().into(),
       CreateOrUpdateType::Update,
       context,
     )
@@ -200,6 +209,7 @@ impl Perform for StickyPost {
       context.pool(),
     )
     .await?;
+    check_community_deleted_or_removed(orig_post.community_id, context.pool()).await?;
 
     // Verify that only the mods can sticky
     is_mod_or_admin(
@@ -212,10 +222,11 @@ impl Perform for StickyPost {
     // Update the post
     let post_id = data.post_id;
     let stickied = data.stickied;
-    let updated_post = blocking(context.pool(), move |conn| {
+    let updated_post: ApubPost = blocking(context.pool(), move |conn| {
       Post::update_stickied(conn, post_id, stickied)
     })
-    .await??;
+    .await??
+    .into();
 
     // Mod tables
     let form = ModStickyPostForm {
@@ -231,8 +242,8 @@ impl Perform for StickyPost {
     // Apub updates
     // TODO stickied should pry work like locked for ease of use
     CreateOrUpdatePost::send(
-      &updated_post,
-      &local_user_view.person,
+      updated_post,
+      &local_user_view.person.clone().into(),
       CreateOrUpdateType::Update,
       context,
     )
